@@ -5,7 +5,7 @@ import pytorch_lightning as pl
 from sklearn.base import BaseEstimator
 from sklearn.model_selection import StratifiedKFold, train_test_split
 
-from typing import Union, List, Dict, Any, Optional
+from typing import Union, List, Dict, Any, Tuple, Optional
 from astrape.utilities.utils_lightning import *
 from astrape.base.experiment_base import BaseExperiment
 from astrape.constants.astrape_constants import *
