@@ -467,7 +467,7 @@ class BaseProject:
                 if self.n_classes:
                     for label_idx in range(self.n_classes):
                         points_dict.update({label_idx: self.X[self.y==label_idx]})
-                        plt.scatter(x=points_dict[label_idx][:,0], y=np.zeros_like(points_dict[label_idx][:,0]+label_idx), label=label_idx)
+                        plt.scatter(x=points_dict[label_idx][:,0], y=np.zeros_like(points_dict[label_idx][:,0])+label_idx, label=label_idx)
                 else:
                     plt.scatter(x=self.X[:,0], y=np.zeros_like(self.X[:,0]))
                 plt.title('Data Distribution')
