@@ -9,6 +9,7 @@ import matplotlib.pyplot as plt
 from torchmetrics import AUROC
 from torchmetrics.functional import dice_score
 from typing import Union, List, Dict, Any, Optional, Tuple
+from torch.nn import functional as F
 
 def column_or_1d(y):
     y = torch.as_tensor(y)
@@ -155,7 +156,6 @@ class R2Score():
 
 class CEDiceLossMetrics():
     def __init__(self, n_classes):
-        self.loss_function = nn.CrossEntropyLoss()
         self.n_classes = n_classes
     @staticmethod
     def accuracy(y_hat, labels):
@@ -177,22 +177,12 @@ class CEDiceLossMetrics():
         labels : "torch.Tensor"
     ):
         
-        loss = self.loss_function(y_hat, labels.reshape(-1)).squeeze()
-        """
-        loss += dice_loss(
-                    F.softmax(y_hat, dim=1).float(),
-                    F.one_hot(labels, self.n_classes).permute(0,3,1,2).float(),
-                    multiclass=True
-                )
+        loss = F.cross_entropy(y_hat, labels.long().squeeze(), ignore_index=250).squeeze()
         
-        """
-        loss += dice_score(F.softmax(y_hat, dim=1).float(), labels.reshape(-1)).squeeze()
         accuracy = self.accuracy(y_hat, labels)
         auc = self.auc(y_hat, labels)
         return loss, accuracy, auc
 
-
-
 def dice_coeff(
     input: Tensor,
     target: Tensor,
